@@ -29,6 +29,11 @@ def generate_refline(bound_l: np.ndarray,
     if bound_l.shape[0] != bound_r.shape[0]:
         raise ValueError("Bound coordinate arrays must hold same length!")
 
+    # check if provided data is closed --> remove closure
+    if np.hypot(bound_l[0, 0] - bound_l[-1, 0], bound_l[0, 1] - bound_l[-1, 1]) < 0.1:
+        bound_l = bound_l[:-1, :]
+        bound_r = bound_r[:-1, :]
+
     # -- create initial center line (based on both bounds) -------------------------------------------------------------
     center_line = 0.5 * (bound_r + bound_l)
 
@@ -44,12 +49,12 @@ def generate_refline(bound_l: np.ndarray,
     # To create a valid polygon with definite enclosure of normal vectors at start and end, the polygon is extended
     # at start and end (first/last vector along bound is added again)
     both_tb = np.row_stack((
-        bound_l[0, :] - np.diff(bound_l[:2, :], axis=0),
+        bound_l[0, :] - np.diff(bound_l[:2, :] * 0.5, axis=0),
         bound_l,
-        bound_l[-1, :] + np.diff(bound_l[-2:, :], axis=0),
-        bound_r[-1, :] + np.diff(bound_r[-2:, :], axis=0),
+        bound_l[-1, :] + np.diff(bound_l[-2:, :] * 0.5, axis=0),
+        bound_r[-1, :] + np.diff(bound_r[-2:, :] * 0.5, axis=0),
         np.flipud(bound_r),
-        bound_r[0, :] - np.diff(bound_r[:2, :], axis=0)
+        bound_r[0, :] - np.diff(bound_r[:2, :] * 0.5, axis=0)
     ))
     track_polygon = Polygon(both_tb)
 
@@ -58,7 +63,7 @@ def generate_refline(bound_l: np.ndarray,
                            input_rl=iter_track)
     n = 0
     temp_iter_track = np.copy(iter_track)
-    while bool_check or n > 500:
+    while bool_check and not n > 500:
         temp_iter_track = movmean_smoothing(input_rl=temp_iter_track,
                                             window_size=9)
         n += 1
@@ -423,7 +428,7 @@ def smooth_sections(input_rl: np.ndarray,
     output_rl = np.zeros((length_input, 2))  # Make all output arrays the same size with zeros
     section_row_indices = np.hstack((section_row_indices, [length_input]))
 
-    print('sections started')
+    # print('sections started')
 
     # For each section, smooth until no intersects exist
     for row in range(num_sections):
@@ -451,7 +456,7 @@ def smooth_sections(input_rl: np.ndarray,
         # If no intersects exist from the beginning, continue to the next section
         if rows_with_intersect.dtype == bool and angle_bool is True:
             output_rl[sec_start:sec_end, :] = section
-            print('section ' + str(row + 1) + ' of ' + str(num_sections) + ' finished')
+            # print('section ' + str(row + 1) + ' of ' + str(num_sections) + ' finished')
             continue
 
         # Tier 1: remove all intersects from the section
